# File: LuckiamuteStreams.R
# Purpose: Example linear GRTS survey designs for Lukiamute Watershed Council
#          streams
# Programmers: Tony Olsen and Tom Kincaid
# Date: April 17, 2005
# Last Modified: October 13, 2006

# Load the spsurvey library

library(spsurvey)

# Read the attribute table from the shapefile

att <- read.dbf("luck-ash")
cat("The initial six lines in the attribute data frame follow:\n\n")
print(head(att))

# Examine attributes that will be used to define strata and unequal probability
# categories (mdcaty)

cat("\nA table displaying the number of streams for each stream type follows\n   Note: 0=perennial stream and 610=intermittent stream\n")
print(table(att$MINOR2))

cat("\nA table displaying the number of streams for each Strahler stream order follows\n   Note: 1=headwater stream\n")
print(table(att$STRAHLER))

# Summarize frame stream length (km) by Strahler stream order

allsize <- sum(att$LENGTH)
strsize <- tapply(att$LENGTH, att$STRAHLER, sum)
mnsize <- tapply(att$LENGTH, att$MINOR2, sum)
strmnsize <- tapply(att$LENGTH, list(att$STRAHLER, att$MINOR2), sum)
rslt <- rbind(cbind(strmnsize, Sum=strsize), Sum=c(mnsize, allsize))/1000
names(dimnames(rslt)) <- list("Strahler", "Stream Type")
cat("\nA table displaying the cross-tabulation of sum of stream length for Strahler \nstream order and stream type follows:\n\n")
print(rslt)
cat("\n")

# Create the stratum variable

att$PerInt <- as.factor(att$MINOR2)
levels(att$PerInt) <- list(Perennial="0", Intermittent="610")

# Create the mdcaty variable

att$strahcat <- as.factor(att$STRAHLER)
levels(att$strahcat) <- list("1st"=c("0","1"), "2nd"="2", "3rd+"=c("3","4","5"))

# Four example GRTS survey designs follow

# Equal probability GRTS survey design

cat("\nEqual probability GRTS survey design\n")

# Create the design list

Equaldsgn <- list(None=list(panel=c(Panel_1=50), seltype="Equal"))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Equalsites <- grts(design=Equaldsgn,
                   DesignID="LuckEQ",
                   type.frame="linear",
                   src.frame="shapefile",
                   in.shape="luck-ash",
                   att.frame=att,
                   prjfilename="luck-ash",
                   out.shape="Luck.EqualSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Equalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Equalsites))

# Stratified GRTS survey design with an oversample

cat("\nStratified GRTS survey design with an oversample\n")

# Create the design list

Stratdsgn <- list(Perennial=list(panel=c(Panel_1=50),
                                 seltype="Equal",
                                 over=50),
                  Intermittent=list(panel=c(Panel_1=50),
                                    seltype="Equal",
                                    over=50))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Stratsites <- grts(design=Stratdsgn,
                   DesignID="LuckST",
                   type.frame="linear",
                   src.frame="shapefile",
                   in.shape="luck-ash",
                   att.frame=att,
                   stratum="PerInt",
                   prjfilename="luck-ash",
                   out.shape="Luck.StratifySites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Stratsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Stratsites))

# Unequal probability GRTS survey design with an oversample and stratification

cat("\nUnequal probability GRTS survey design with an oversample and stratification\n")

# Create the design list

Unequaldsgn <- list(Perennial=list(panel=c(Panel_1=75),
                                   seltype="Unequal",
                                   caty.n=c("1st"=25, "2nd"=25, "3rd+"=25),
                                   over=36),
                    Intermittent=list(panel=c(Panel_1=25),
                                      seltype="Unequal",
                                      caty.n=c("1st"=17, "2nd"=5, "3rd+"=3),
                                      over=0))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Unequalsites <- grts(design=Unequaldsgn,
                   DesignID="LuckUN",
                   type.frame="linear",
                   src.frame="shapefile",
                   in.shape="luck-ash",
                   att.frame=att,
                   stratum="PerInt",
                   mdcaty="strahcat",
                   prjfilename="luck-ash",
                   out.shape="Luck.UnEqualSites"
                   )
# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Unequalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Unequalsites))

# Unequal probability GRTS survey design with an oversample and a panel
# structure for survey over time

cat("\nUnequal probability GRTS survey design with an oversample and a panel structure \nfor survey over time\n")

# Create the design list

Paneldsgn <- list(Perennial=list(panel=c(Year1=17, Year2=17, YearAll=16),
                                 seltype="Unequal",
                                 caty.n=c("1st"=15, "2nd"=15, "3rd+"=20 ),
                                 over=50),
                  Intermittent=list(panel=c(YearOnce=25),
                                    seltype="Unequal",
                                    caty.n=c("1st"=17, "2nd"=5, "3rd+"=3 ),
                                    over=0))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Panelsites <- grts(design=Paneldsgn,
                   DesignID="LuckPan",
                   type.frame="linear",
                   src.frame="shapefile",
                   in.shape="luck-ash",
                   att.frame=att,
                   stratum="PerInt",
                   mdcaty="strahcat",
                   prjfilename="luck-ash",
                   out.shape="Luck.PanelSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Panelsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Panelsites))
